[llvm] r204983 - PBQP: Minor cleanups to r204857

David Blaikie dblaikie at gmail.com
Thu Mar 27 16:42:21 PDT 2014


Author: dblaikie
Date: Thu Mar 27 18:42:21 2014
New Revision: 204983

URL: http://llvm.org/viewvc/llvm-project?rev=204983&view=rev
Log:
PBQP: Minor cleanups to r204857

* Use assignment instead of swap (since the original value is being
  destroyed anyway)

* Rename "updateAdjEdgeId" to "setAdjEdgeId"

Modified:
    llvm/trunk/include/llvm/CodeGen/PBQP/Graph.h

Modified: llvm/trunk/include/llvm/CodeGen/PBQP/Graph.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/CodeGen/PBQP/Graph.h?rev=204983&r1=204982&r2=204983&view=diff
==============================================================================
--- llvm/trunk/include/llvm/CodeGen/PBQP/Graph.h (original)
+++ llvm/trunk/include/llvm/CodeGen/PBQP/Graph.h Thu Mar 27 18:42:21 2014
@@ -70,12 +70,12 @@ namespace PBQP {
       void removeAdjEdgeId(Graph &G, NodeId ThisNId, AdjEdgeIdx Idx) {
         // Swap-and-pop for fast removal.
         //   1) Update the adj index of the edge currently at back().
-        //   2) Swap Edge at Idx with back().
+        //   2) Move last Edge down to Idx.
         //   3) pop_back()
         // If Idx == size() - 1 then the updateAdjEdgeIdx and swap are
         // redundant, but both operations are cheap.
-        G.getEdge(AdjEdgeIds.back()).updateAdjEdgeIdx(ThisNId, Idx);
-        std::swap(AdjEdgeIds[Idx], AdjEdgeIds.back());
+        G.getEdge(AdjEdgeIds.back()).setAdjEdgeIdx(ThisNId, Idx);
+        AdjEdgeIds[Idx] = AdjEdgeIds.back();
         AdjEdgeIds.pop_back();
       }
 
@@ -125,7 +125,7 @@ namespace PBQP {
         connectToN(G, ThisEdgeId, 1);
       }
 
-      void updateAdjEdgeIdx(NodeId NId, typename NodeEntry::AdjEdgeIdx NewIdx) {
+      void setAdjEdgeIdx(NodeId NId, typename NodeEntry::AdjEdgeIdx NewIdx) {
         if (NId == NIds[0])
           ThisEdgeAdjIdxs[0] = NewIdx;
         else {
@@ -70,12 +70,12 @@ namespace PBQP {
         //   3) pop_back()
-        // If Idx == size() - 1 then the updateAdjEdgeIdx and swap are
+        // If Idx == size() - 1 then the setAdjEdgeIdx and swap are
         // redundant, but both operations are cheap.





More information about the llvm-commits mailing list